@@ -31,6 +31,7 @@ __all__ = (
     "FilterNameType",
     "FindingReasonCodeType",
     "FindingType",
+    "InstanceRecommendationFindingReasonCodeType",
     "JobFilterNameType",
     "JobStatusType",
     "LambdaFunctionMemoryMetricNameType",
@@ -42,6 +43,7 @@ __all__ = (
     "LambdaFunctionRecommendationFindingType",
     "MetricNameType",
     "MetricStatisticType",
+    "PlatformDifferenceType",
     "RecommendationSourceTypeType",
     "ResourceTypeType",
     "StatusType",
@@ -89,11 +91,19 @@ ExportableAutoScalingGroupFieldType = Literal[
     "RecommendationOptionsStorage",
     "RecommendationOptionsVcpus",
     "UtilizationMetricsCpuMaximum",
+    "UtilizationMetricsDiskReadBytesPerSecondMaximum",
+    "UtilizationMetricsDiskReadOpsPerSecondMaximum",
+    "UtilizationMetricsDiskWriteBytesPerSecondMaximum",
+    "UtilizationMetricsDiskWriteOpsPerSecondMaximum",
     "UtilizationMetricsEbsReadBytesPerSecondMaximum",
     "UtilizationMetricsEbsReadOpsPerSecondMaximum",
     "UtilizationMetricsEbsWriteBytesPerSecondMaximum",
     "UtilizationMetricsEbsWriteOpsPerSecondMaximum",
     "UtilizationMetricsMemoryMaximum",
+    "UtilizationMetricsNetworkInBytesPerSecondMaximum",
+    "UtilizationMetricsNetworkOutBytesPerSecondMaximum",
+    "UtilizationMetricsNetworkPacketsInPerSecondMaximum",
+    "UtilizationMetricsNetworkPacketsOutPerSecondMaximum",
 ]
 ExportableInstanceFieldType = Literal[
     "AccountId",
@@ -106,6 +116,7 @@ ExportableInstanceFieldType = Literal[
     "CurrentStorage",
     "CurrentVCpus",
     "Finding",
+    "FindingReasonCodes",
     "InstanceArn",
     "InstanceName",
     "LastRefreshTimestamp",
@@ -115,6 +126,7 @@ ExportableInstanceFieldType = Literal[
     "RecommendationOptionsNetwork",
     "RecommendationOptionsOnDemandPrice",
     "RecommendationOptionsPerformanceRisk",
+    "RecommendationOptionsPlatformDifferences",
     "RecommendationOptionsProjectedUtilizationMetricsCpuMaximum",
     "RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum",
     "RecommendationOptionsStandardOneYearNoUpfrontReservedPrice",
@@ -124,11 +136,19 @@ ExportableInstanceFieldType = Literal[
     "RecommendationsSourcesRecommendationSourceArn",
     "RecommendationsSourcesRecommendationSourceType",
     "UtilizationMetricsCpuMaximum",
+    "UtilizationMetricsDiskReadBytesPerSecondMaximum",
+    "UtilizationMetricsDiskReadOpsPerSecondMaximum",
+    "UtilizationMetricsDiskWriteBytesPerSecondMaximum",
+    "UtilizationMetricsDiskWriteOpsPerSecondMaximum",
     "UtilizationMetricsEbsReadBytesPerSecondMaximum",
     "UtilizationMetricsEbsReadOpsPerSecondMaximum",
     "UtilizationMetricsEbsWriteBytesPerSecondMaximum",
     "UtilizationMetricsEbsWriteOpsPerSecondMaximum",
     "UtilizationMetricsMemoryMaximum",
+    "UtilizationMetricsNetworkInBytesPerSecondMaximum",
+    "UtilizationMetricsNetworkOutBytesPerSecondMaximum",
+    "UtilizationMetricsNetworkPacketsInPerSecondMaximum",
+    "UtilizationMetricsNetworkPacketsOutPerSecondMaximum",
 ]
 ExportableLambdaFunctionFieldType = Literal[
     "AccountId",
@@ -181,9 +201,27 @@ ExportableVolumeFieldType = Literal[
     "VolumeArn",
 ]
 FileFormatType = Literal["Csv"]
-FilterNameType = Literal["Finding", "RecommendationSourceType"]
+FilterNameType = Literal["Finding", "FindingReasonCodes", "RecommendationSourceType"]
 FindingReasonCodeType = Literal["MemoryOverprovisioned", "MemoryUnderprovisioned"]
 FindingType = Literal["NotOptimized", "Optimized", "Overprovisioned", "Underprovisioned"]
+InstanceRecommendationFindingReasonCodeType = Literal[
+    "CPUOverprovisioned",
+    "CPUUnderprovisioned",
+    "DiskIOPSOverprovisioned",
+    "DiskIOPSUnderprovisioned",
+    "DiskThroughputOverprovisioned",
+    "DiskThroughputUnderprovisioned",
+    "EBSIOPSOverprovisioned",
+    "EBSIOPSUnderprovisioned",
+    "EBSThroughputOverprovisioned",
+    "EBSThroughputUnderprovisioned",
+    "MemoryOverprovisioned",
+    "MemoryUnderprovisioned",
+    "NetworkBandwidthOverprovisioned",
+    "NetworkBandwidthUnderprovisioned",
+    "NetworkPPSOverprovisioned",
+    "NetworkPPSUnderprovisioned",
+]
 JobFilterNameType = Literal["JobStatus", "ResourceType"]
 JobStatusType = Literal["Complete", "Failed", "InProgress", "Queued"]
 LambdaFunctionMemoryMetricNameType = Literal["Duration"]
@@ -197,13 +235,28 @@ LambdaFunctionRecommendationFindingReasonCodeType = Literal[
 LambdaFunctionRecommendationFindingType = Literal["NotOptimized", "Optimized", "Unavailable"]
 MetricNameType = Literal[
     "Cpu",
+    "DISK_READ_BYTES_PER_SECOND",
+    "DISK_READ_OPS_PER_SECOND",
+    "DISK_WRITE_BYTES_PER_SECOND",
+    "DISK_WRITE_OPS_PER_SECOND",
     "EBS_READ_BYTES_PER_SECOND",
     "EBS_READ_OPS_PER_SECOND",
     "EBS_WRITE_BYTES_PER_SECOND",
     "EBS_WRITE_OPS_PER_SECOND",
     "Memory",
+    "NETWORK_IN_BYTES_PER_SECOND",
+    "NETWORK_OUT_BYTES_PER_SECOND",
+    "NETWORK_PACKETS_IN_PER_SECOND",
+    "NETWORK_PACKETS_OUT_PER_SECOND",
 ]
 MetricStatisticType = Literal["Average", "Maximum"]
+PlatformDifferenceType = Literal[
+    "Hypervisor",
+    "InstanceStoreAvailability",
+    "NetworkInterface",
+    "StorageInterface",
+    "VirtualizationType",
+]
 RecommendationSourceTypeType = Literal[
     "AutoScalingGroup", "EbsVolume", "Ec2Instance", "LambdaFunction"
 ]
